#!/usr/bin/env python3

from contentmonster.classes.config import MonsterConfig
from contentmonster.classes.vesselthread import VesselThread
from contentmonster.classes.shorethread import ShoreThread

from multiprocessing import Manager
from argparse import ArgumentParser

import pathlib
import time
import logging
import signal

# Setup basic logging
logging.basicConfig(level=logging.INFO)

def setup_signal_handlers(shore, threads):
    def signal_handler(signum, frame):
        logging.info("Signal received - stopping threads")
        shore.terminate()
        for thread in threads:
            thread.terminate()
        exit(0)
    signal.signal(signal.SIGINT, signal_handler)
    signal.signal(signal.SIGTERM, signal_handler)

def main():
    parser = ArgumentParser(description="ContentMonster Worker")
    parser.add_argument("-c", "--config", help="Path to configuration file")
    args = parser.parse_args()

    if args.config:
        config_path = args.config
    else:
        config_path = "settings.ini"
    
    config = MonsterConfig()

    try:
        config.readFile(config_path)
    except Exception as e:
        logging.error(f"Failed to read configuration: {e}")
        return

    with Manager() as manager:
        state = manager.dict()
        state["files"] = manager.list()
        state["config"] = config

        threads = []

        for vessel in config.vessels:
            thread = VesselThread(vessel, state)
            thread.start()
            threads.append(thread)

        shore = ShoreThread(state)
        shore.start()

        setup_signal_handlers(shore, threads)

        while True:
            try:
                time.sleep(10)
            except Exception as e:
                logging.error(f"Unexpected error: {e}")
                break

if __name__ == '__main__':
    main()